<p align="center">
  <a href="" rel="noopener">
 <img width=200px height=200px src="https://i.imgur.com/nkMr2fl.png" alt="Project logo"></a>
</p>

<h1 align="center">Spyctl</h1>

Spyctl, is a command-line utility for viewing and managing Spyderbat Resources. It provides basic
mechanisms for retrieving and uploading data via the Spyderbat API.

Spyctl is the answer for those wanting a command-line solution for interacting fully with their Spyderbat
environment.

---

<p align="center"> 
    <br> 
</p>

## Getting Started <a name = "getting_started"></a>

Follow the [Getting Started Guide](https://spyctl.readthedocs.io/en/latest/getting_started/getting_started.html)

Or if you already have Spyctl installed try the [Basics Tutorial](https://github.com/spyderbat/spyctl/blob/master/docs/tutorials/spyctl_basics.rst)

## Support <a name = "support"></a>

If you need support, you can reach out to us at dev@spyderbat.com or on our [community Slack workspace](https://join.slack.com/t/spyderbatcommunity/shared_invite/zt-1ncqumr1c-WVVRwJTNfTQSW2Y8_maGOw)


## ✍️ Authors <a name = "authors"></a>

- [@brent-spyder](https://github.com/brent-spyder) - Developer
- [@spyder-kyle](https://github.com/spyder-kyle) - Developer
